@@ -219,6 +219,16 @@ impl Image {
             .circb(x, y, radius, self.palette[color as usize]);
     }
 
+    pub fn elli(&mut self, x: f64, y: f64, width: f64, height: f64, color: Color) {
+        self.canvas
+            .elli(x, y, width, height, self.palette[color as usize]);
+    }
+
+    pub fn ellib(&mut self, x: f64, y: f64, width: f64, height: f64, color: Color) {
+        self.canvas
+            .ellib(x, y, width, height, self.palette[color as usize]);
+    }
+
     pub fn tri(&mut self, x1: f64, y1: f64, x2: f64, y2: f64, x3: f64, y3: f64, color: Color) {
         self.canvas
             .tri(x1, y1, x2, y2, x3, y3, self.palette[color as usize]);
@@ -229,6 +239,10 @@ impl Image {
             .trib(x1, y1, x2, y2, x3, y3, self.palette[color as usize]);
     }
 
+    pub fn fill(&mut self, x: f64, y: f64, color: Color) {
+        self.canvas.fill(x, y, self.palette[color as usize]);
+    }
+
     pub fn blt(
         &mut self,
         x: f64,
